.. @+leo-ver=5-thin
.. @+node:peckj.20130503092808.1679: * @file leo.rst
.. @@language rest
leo Package
===========

:mod:`leo` Package
------------------

.. automodule:: leo.__init__
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    leo.core
    leo.extensions
    leo.external
    leo.plugins

.. @-leo
